@@ -1,10 +1,16 @@
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
+
 /* WCC: These functions are to export and access pointers in R.
  *
  * Wei-Chen Chen, Mar 2013.
+ * Modified June 2015, Higgs and Schmidt.
  */
 
 #include "pkg_global.h"
 
+
 void set_BLACS_APTS_in_R(){
 	/* Define R objects. */
 	SEXP R_apts;
@@ -64,7 +70,6 @@ void get_BLACS_APTS_from_R(){
         if(R_apts == R_NilValue){
                 error(".__BLACS_APTS__ is not found in .GlobalEnv");
         }
-
         /* Get pointers. */
         BLACS_APTS_ptr = R_ExternalPtrAddr(R_apts);
 
@@ -98,12 +103,6 @@ void get_BLACS_APTS_from_R(){
 	if(myrank == 0){
 		REprintf("  %s (v): %d %d %d %d %d.\n", __FILE__, BI_MaxNCtxt,
 			BI_MaxNSysCtxt, BI_Iam, BI_Np, BI_AuxBuff);
-/* Not a good idea to print NULL pointers.
-		REprintf("  %s (v): %d %d %d %d.\n", __FILE__, *BI_ReadyB,
-			*BI_ActiveQ, **BI_MyContxts, *BI_COMM_WORLD);
-		REprintf("  %s (v): %d %d.\n", __FILE__, *BI_SysContxts,
-			*BI_Stats);
-*/
 		REprintf("  %s (v): %d %d %d.\n", __FILE__, BI_AuxBuff.Len,
 			BI_AuxBuff.nAops, BI_AuxBuff.N);
 		REprintf("  %s (a): %x %x %x %x %x.\n", __FILE__, &BI_MaxNCtxt,
